@@ -3,15 +3,10 @@
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
-import os
 import pytest
-import yaml
 
 from typing import Any, Dict
 
-from swh.scheduler.tests.conftest import swh_app  # noqa
-from swh.storage.tests.conftest import *  # noqa
-
 
 @pytest.fixture
 def swh_loader_config(swh_storage_backend_config) -> Dict[str, Any]:
@@ -41,19 +36,3 @@ def swh_loader_config(swh_storage_backend_config) -> Dict[str, Any]:
         "save_data_path": "",
         "temp_directory": "/tmp",
     }
-
-
-@pytest.fixture
-def swh_config(swh_loader_config, monkeypatch, tmp_path):
-    conffile = os.path.join(str(tmp_path), "loader.yml")
-    with open(conffile, "w") as f:
-        f.write(yaml.dump(swh_loader_config))
-    monkeypatch.setenv("SWH_CONFIG_FILENAME", conffile)
-    return conffile
-
-
-@pytest.fixture(scope="session")
-def celery_includes():
-    return [
-        "swh.loader.svn.tasks",
-    ]
